summaryrefslogtreecommitdiffstats
path: root/kplato/kptnode.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kplato/kptnode.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kplato/kptnode.h')
-rw-r--r--kplato/kptnode.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kplato/kptnode.h b/kplato/kptnode.h
index d6a6bbef..95d7c24b 100644
--- a/kplato/kptnode.h
+++ b/kplato/kptnode.h
@@ -59,8 +59,8 @@ class Node {
public:
enum ConstraintType { ASAP, ALAP, MustStartOn, MustFinishOn, StartNotEarlier, FinishNotLater, FixedInterval };
- Node(Node *tqparent = 0);
- Node(Node &node, Node *tqparent = 0);
+ Node(Node *parent = 0);
+ Node(Node &node, Node *parent = 0);
// Declare the class abstract
@@ -374,7 +374,7 @@ public:
virtual bool legalToLink(Node *, Node *) { return false; }
/// Check if this node has any dependent child nodes
virtual bool isEndNode() const;
/// Check if this node has any dependent tqparent nodes
virtual bool isStartNode() const;
virtual void clearProxyRelations() {}
virtual void addParentProxyRelations(TQPtrList<Relation> &) {}
@@ -477,11 +477,11 @@ public:
/// Create a new schedule.
Schedule *createSchedule(TQString name, Schedule::Type type, long id);
/// Create a new schedule.
- Schedule *createSchedule(Schedule *tqparent);
+ Schedule *createSchedule(Schedule *parent);
/// Set deleted = onoff for schedule with id
void setScheduleDeleted(long id, bool onoff);
/// Set tqparent schedule recursivly
virtual void setParentSchedule(Schedule *sch);
DateTime startTime()
@@ -374,7 +374,7 @@ public:
/// Check if this node has any dependent child nodes
virtual bool isEndNode() const;
- /// Check if this node has any dependent tqparent nodes
+ /// Check if this node has any dependent parent nodes
virtual bool isStartNode() const;
virtual void clearProxyRelations() {}
@@ -477,11 +477,11 @@ public:
/// Set deleted = onoff for schedule with id
void setScheduleDeleted(long id, bool onoff);
- /// Set tqparent schedule recursivly
+ /// Set parent schedule recursivly
virtual void setParentSchedule(Schedule *sch);
DateTime startTime()